Learn R Programming

messy (version 0.1.0)

add_whitespace: Add whitespaces

Description

Randomly add whitespaces to the end of some values in all or a subset of columns.

Usage

add_whitespace(data, cols = NULL, messiness = 0.1)

Value

a dataframe the same size as the input data.

Arguments

data

input dataframe

cols

set of columns to apply transformation to. If NULL will apply to all columns. Default NULL.

messiness

Percentage of values to change. Must be between 0 and 1. Default 0.1.

Examples

Run this code
add_whitespace(mtcars)

Run the code above in your browser using DataLab